@@ -1,25 +1,12 @@
 package Weed::Symbols;
-use Weed::Perl;
+use strict;
+use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.0003';
 
 use base 'Exporter';
 
 our @EXPORT = qw(
-  $_tab_
-  $_space_
-  $_break_
-
-  $_open_brace_
-  $_close_brace_
-  $_open_bracket_
-  $_close_bracket_
-
-  $_period_
-  $_colon_
-  $_comma_
-  $_comment_
-
   $_nan_
   $_inf_
 
@@ -48,30 +35,8 @@ our @EXPORT = qw(
   $_eventOut_
   $_exposedField_
   $_field_
-  
-  $_open_parenthesis_
-  $_close_parenthesis_
-  $_in_
-  $_out_
-
 );
 
-# General
-our $_tab_   = ' ';
-our $_space_ = ' ';
-our $_break_ = "\n";
-
-# Terminal symbols
-our $_open_brace_    = '{';
-our $_close_brace_   = '}';
-our $_open_bracket_  = '[';
-our $_close_bracket_ = ']';
-our $_period_        = '.';
-our $_colon_         = ':';
-our $_comma_         = ',';
-
-our $_comment_ = '#';
-
 # Field Values Symbols
 our $_nan_ = 'nan0x7ffffe00';
 our $_inf_ = 'inf';
@@ -104,14 +69,5 @@ our $_eventOut_     = 'eventOut';
 our $_exposedField_ = 'exposedField';
 our $_field_        = 'field';
 
-# Concept
-our $_open_parenthesis_    = '(';
-our $_close_parenthesis_   = ')';
-#our $_open_angle_bracket_  = '<';
-#our $_close_angle_bracket_ = '>';
-#our $_swung_dash_          = '~';
-our $_in_                  = 'in';
-our $_out_                 = 'out';
-
 1;
 __END__
